@@ -25,8 +25,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 log = logging.getLogger(__name__)
 
-from bokeh.util.api import general, dev ; general, dev
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -47,7 +45,6 @@ from .code import CodeHandler
 # General API
 #-----------------------------------------------------------------------------
 
-@general((1,0,0))
 class NotebookHandler(CodeHandler):
     ''' A Handler that uses code in a Jupyter notebook for modifying Bokeh
     Documents.
