@@ -240,7 +240,6 @@ class HasProps(with_metaclass(MetaHasProps, object)):
         a few situations:
 
         * short circuit all property machinery for ``_private`` attributes
-        * handle setting ``__deprecated_attributes__``
         * suggest similar attribute names on attribute errors
 
         Args:
@@ -258,9 +257,9 @@ class HasProps(with_metaclass(MetaHasProps, object)):
             return
 
         props = sorted(self.properties())
-        deprecated = getattr(self, '__deprecated_attributes__', [])
+        descriptor = getattr(self.__class__, name, None)
 
-        if name in props or name in deprecated:
+        if name in props or (descriptor is not None and descriptor.fset is not None):
             super(HasProps, self).__setattr__(name, value)
         else:
             matches, text = difflib.get_close_matches(name.lower(), props), "similar"
@@ -647,24 +646,18 @@ class HasProps(with_metaclass(MetaHasProps, object)):
 
         '''
         IPython = import_optional('IPython')
+        cls = self.__class__
 
         if IPython:
             from IPython.lib.pretty import RepresentationPrinter
 
-        class _BokehPrettyPrinter(RepresentationPrinter):
-            def __init__(self, output, verbose=False, max_width=79, newline='\n'):
-                super(_BokehPrettyPrinter, self).__init__(output, verbose, max_width, newline)
-                self.type_pprinters[HasProps] = lambda obj, p, cycle: obj._repr_pretty(p, cycle)
-
-        if not IPython:
-            cls = self.__class__
-            raise RuntimeError("%s.%s.pretty() requires IPython" % (cls.__module__, cls.__name__))
-        else:
             stream = StringIO()
-            printer = _BokehPrettyPrinter(stream, verbose, max_width, newline)
+            printer = RepresentationPrinter(stream, verbose, max_width, newline)
             printer.pretty(self)
             printer.flush()
             return stream.getvalue()
+        else:
+            raise RuntimeError("%s.%s.pretty() requires IPython" % (cls.__module__, cls.__name__))
 
     def pprint(self, verbose=False, max_width=79, newline='\n'):
         ''' Print a "pretty" string representation of the object to stdout.
@@ -724,7 +717,7 @@ class HasProps(with_metaclass(MetaHasProps, object)):
         '''
         return self.__class__(**self._property_values)
 
-    def _repr_pretty(self, p, cycle):
+    def _repr_pretty_(self, p, cycle):
         '''
 
         '''
