@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 import datetime
+import time
 import unittest
 import numpy as np
 import pandas as pd
@@ -9,11 +10,11 @@ from copy import copy
 import pytest
 
 from bokeh.core.properties import (field, value,
-    NumberSpec, ColorSpec, Bool, Int, Float, Complex, String,
+    NumberSpec, ColorSpec, Bool, Int, Float, Complex, Date, String,
     Regex, Seq, List, Dict, Tuple, Instance, Any, Interval, Either,
     Enum, Color, DashPattern, Size, Percent, Angle, AngleSpec, StringSpec,
-    DistanceSpec, FontSizeSpec, Override, Include, MinMaxBounds,
-    DataDistanceSpec, ScreenDistanceSpec, ColumnData)
+    DistanceSpec, FontSize, FontSizeSpec, Override, Include, MinMaxBounds,
+    DataDistanceSpec, ScreenDistanceSpec, ColumnData, UnitsSpec)
 
 from bokeh.core.property.containers import PropertyValueColumnData, PropertyValueDict, PropertyValueList
 
@@ -21,6 +22,288 @@ from bokeh.core.has_props import HasProps
 
 from bokeh.models import Plot
 
+SPECS = (NumberSpec, ColorSpec, AngleSpec, StringSpec, DistanceSpec, FontSizeSpec, DataDistanceSpec, ScreenDistanceSpec)
+
+class TestValidateDetailDefault(object):
+
+    def test_Angle(self):
+        p = Angle()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Bool(self):
+        p = Bool()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Complex(self):
+        p = Complex()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Float(self):
+        p = Float()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Int(self):
+        p = Int()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Interval(self):
+        p = Interval(Float, 0.0, 1.0)
+        with pytest.raises(ValueError) as e:
+            p.validate(2)
+        assert not str(e).endswith("ValueError")
+    def test_Percent(self):
+        p = Percent()
+        with pytest.raises(ValueError) as e:
+            p.validate(10)
+        assert not str(e).endswith("ValueError")
+    def test_Size(self):
+        p = Size()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+
+
+    def test_List(self):
+        p = List(Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Seq(self):
+        p = Seq(Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Dict(self):
+        p = Dict(String, Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Tuple(self):
+        p = Tuple(Int, Int)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+
+
+    def test_Color(self):
+        p = Color()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_ColumnData(self):
+        p = ColumnData(String, Seq(Float))
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Date(self):
+        p = Date()
+        with pytest.raises(ValueError) as e:
+            p.validate(p)
+        assert not str(e).endswith("ValueError")
+    def test_DashPattern(self):
+        p = DashPattern()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Either(self):
+        p = Either(Int, Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Enum(self):
+        p = Enum("red", "green")
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_FontSize(self):
+        p = FontSize()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_Instance(self):
+        p = Instance(HasProps)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_MinMaxBounds(self):
+        p = MinMaxBounds()
+        with pytest.raises(ValueError) as e:
+            p.validate(10)
+        assert not str(e).endswith("ValueError")
+    def test_Regex(self):
+        p = Regex("green")
+        with pytest.raises(ValueError) as e:
+            p.validate("junk")
+        assert not str(e).endswith("ValueError")
+    def test_String(self):
+        p = String()
+        with pytest.raises(ValueError) as e:
+            p.validate(10)
+        assert not str(e).endswith("ValueError")
+
+
+    @pytest.mark.parametrize('spec', SPECS)
+    def test_Spec(self, spec):
+        p = spec(default=None)
+        with pytest.raises(ValueError) as e:
+            p.validate(dict(bad="junk"))
+        assert not str(e).endswith("ValueError")
+
+
+@pytest.mark.parametrize('detail', [True, False])
+class TestValidateDetailExplicit(object):
+
+    def test_Angle(self, detail):
+        p = Angle()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Bool(self, detail):
+        p = Bool()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Complex(self, detail):
+        p = Complex()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Float(self, detail):
+        p = Float()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Int(self, detail):
+        p = Int()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Interval(self, detail):
+        p = Interval(Float, 0.0, 1.0)
+        with pytest.raises(ValueError) as e:
+            p.validate(2, detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Percent(self, detail):
+        p = Percent()
+        with pytest.raises(ValueError) as e:
+            p.validate(10, detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Size(self, detail):
+        p = Size()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+
+
+
+
+    def test_List(self, detail):
+        p = List(Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Seq(self, detail):
+        p = Seq(Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Dict(self, detail):
+        p = Dict(String, Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Tuple(self, detail):
+        p = Tuple(Int, Int)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+
+
+
+
+    def test_Color(self, detail):
+        p = Color()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_ColumnData(self, detail):
+        p = ColumnData(String, Seq(Float))
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Date(self, detail):
+        p = Date()
+        with pytest.raises(ValueError) as e:
+            p.validate(p, detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_DashPattern(self, detail):
+        p = DashPattern()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Either(self, detail):
+        p = Either(Int, Float)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Enum(self, detail):
+        p = Enum("red", "green")
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_FontSize(self, detail):
+        p = FontSize()
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Instance(self, detail):
+        p = Instance(HasProps)
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_MinMaxBounds(self, detail):
+        p = MinMaxBounds()
+        with pytest.raises(ValueError) as e:
+            p.validate(10, detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_Regex(self, detail):
+        p = Regex("green")
+        with pytest.raises(ValueError) as e:
+            p.validate("junk", detail)
+        assert str(e).endswith("ValueError") == (not detail)
+    def test_String(self, detail):
+        p = String()
+        with pytest.raises(ValueError) as e:
+            p.validate(10, detail)
+        assert str(e).endswith("ValueError") == (not detail)
+
+
+
+    @pytest.mark.parametrize('spec', SPECS)
+    def test_Spec(self, detail, spec):
+        p = spec(default=None)
+        with pytest.raises(ValueError) as e:
+            p.validate(dict(bad="junk"), detail)
+        assert str(e).endswith("ValueError") == (not detail)
+
+
+
+class Test_Date(object):
+    def test_validate_seconds(self):
+        t = time.time()
+        d = Date()
+        assert d.transform(t) == datetime.date.today()
+
+    def test_validate_milliseconds(self):
+        t = time.time() * 1000
+        d = Date()
+        assert d.transform(t) == datetime.date.today()
+
 class Basictest(unittest.TestCase):
 
     def test_simple_class(self):
@@ -591,12 +874,12 @@ class TestFontSizeSpec(unittest.TestCase):
 
             v = '10%s' % unit
             a.x = v
-            self.assertEqual(a.x, dict(value=v))
+            self.assertEqual(a.x, v)
             self.assertEqual(a.lookup('x').serializable_value(a), dict(value=v))
 
             v = '10.2%s' % unit
             a.x = v
-            self.assertEqual(a.x, dict(value=v))
+            self.assertEqual(a.x, v)
             self.assertEqual(a.lookup('x').serializable_value(a), dict(value=v))
 
             f = '_10%s' % unit
@@ -612,12 +895,12 @@ class TestFontSizeSpec(unittest.TestCase):
         for unit in css_units.upper().split("|"):
             v = '10%s' % unit
             a.x = v
-            self.assertEqual(a.x, dict(value=v))
+            self.assertEqual(a.x, v)
             self.assertEqual(a.lookup('x').serializable_value(a), dict(value=v))
 
             v = '10.2%s' % unit
             a.x = v
-            self.assertEqual(a.x, dict(value=v))
+            self.assertEqual(a.x, v)
             self.assertEqual(a.lookup('x').serializable_value(a), dict(value=v))
 
             f = '_10%s' % unit
@@ -1192,6 +1475,7 @@ class TestProperties(unittest.TestCase):
         prop = String()
 
         self.assertTrue(prop.is_valid(None))
+
         self.assertFalse(prop.is_valid(False))
         self.assertFalse(prop.is_valid(True))
         self.assertFalse(prop.is_valid(0))
@@ -1200,11 +1484,60 @@ class TestProperties(unittest.TestCase):
         self.assertFalse(prop.is_valid(1.0))
         self.assertFalse(prop.is_valid(1.0+1.0j))
         self.assertTrue(prop.is_valid(""))
+        self.assertTrue(prop.is_valid("6"))
         self.assertFalse(prop.is_valid(()))
         self.assertFalse(prop.is_valid([]))
         self.assertFalse(prop.is_valid({}))
         self.assertFalse(prop.is_valid(Foo()))
 
+    def test_FontSize(self):
+
+        prop = FontSize()
+
+        self.assertTrue(prop.is_valid(None))
+
+        css_units = "%|em|ex|ch|ic|rem|vw|vh|vi|vb|vmin|vmax|cm|mm|q|in|pc|pt|px"
+
+        for unit in css_units.split("|"):
+            v = '10%s' % unit
+            self.assertTrue(prop.is_valid(v))
+
+            v = '10.2%s' % unit
+            self.assertTrue(prop.is_valid(v))
+
+            v = '_10%s' % unit
+            self.assertFalse(prop.is_valid(v))
+
+            v = '_10.2%s' % unit
+            self.assertFalse(prop.is_valid(v))
+
+        for unit in css_units.upper().split("|"):
+            v = '10%s' % unit
+            self.assertTrue(prop.is_valid(v))
+
+            v = '10.2%s' % unit
+            self.assertTrue(prop.is_valid(v))
+
+            v = '_10%s' % unit
+            self.assertFalse(prop.is_valid(v))
+
+            v = '_10.2%s' % unit
+            self.assertFalse(prop.is_valid(v))
+
+        self.assertFalse(prop.is_valid(False))
+        self.assertFalse(prop.is_valid(True))
+        self.assertFalse(prop.is_valid(0))
+        self.assertFalse(prop.is_valid(1))
+        self.assertFalse(prop.is_valid(0.0))
+        self.assertFalse(prop.is_valid(1.0))
+        self.assertFalse(prop.is_valid(1.0+1.0j))
+        self.assertFalse(prop.is_valid(""))
+        self.assertFalse(prop.is_valid(()))
+        self.assertFalse(prop.is_valid([]))
+        self.assertFalse(prop.is_valid({}))
+        self.assertFalse(prop.is_valid(Foo()))
+
+
     def test_Regex(self):
         with self.assertRaises(TypeError):
             prop = Regex()
@@ -1769,18 +2102,35 @@ def test_strict_dataspec_key_values():
             f.x = dict(field="foo", units="junk")
 
 def test_dataspec_dict_to_serializable():
-    for typ in (NumberSpec, StringSpec, FontSizeSpec, ColorSpec, DataDistanceSpec, ScreenDistanceSpec):
+    for typ in (NumberSpec, StringSpec, FontSizeSpec, ColorSpec):
         class Foo(HasProps):
             x = typ("x")
         foo = Foo(x=dict(field='foo'))
         props = foo.properties_with_values(include_defaults=False)
-        if typ is DataDistanceSpec:
-            assert props['x']['units'] == 'data'
-        elif typ is ScreenDistanceSpec:
-            assert props['x']['units'] == 'screen'
         assert props['x']['field'] == 'foo'
         assert props['x'] is not foo.x
 
+def test_DataDistanceSpec():
+    assert issubclass(DataDistanceSpec, UnitsSpec)
+    class Foo(HasProps):
+        x = DataDistanceSpec("x")
+    foo = Foo(x=dict(field='foo'))
+    props = foo.properties_with_values(include_defaults=False)
+    assert props['x']['units'] == 'data'
+    assert props['x']['field'] == 'foo'
+    assert props['x'] is not foo.x
+
+def test_ScreenDistanceSpec():
+    assert issubclass(ScreenDistanceSpec, UnitsSpec)
+    class Foo(HasProps):
+        x = ScreenDistanceSpec("x")
+    foo = Foo(x=dict(field='foo'))
+    props = foo.properties_with_values(include_defaults=False)
+    assert props['x']['units'] == 'screen'
+    assert props['x']['field'] == 'foo'
+    assert props['x'] is not foo.x
+
+
 def test_strict_unitspec_key_values():
     class FooUnits(HasProps):
         x = DistanceSpec("x")
