@@ -49,7 +49,7 @@ event object that triggered the callback.
 from __future__ import absolute_import
 
 import logging
-logger = logging.getLogger(__file__)
+logger = logging.getLogger(__name__)
 
 from .util.future import with_metaclass
 
