@@ -9,8 +9,7 @@ from ..core.property_mixins import LineProps, FillProps
 from ..core.query import find
 from ..core.validation import error, warning
 from ..core.validation.errors import REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
-from ..core.validation.warnings import MISSING_RENDERERS, NO_DATA_RENDERERS
-from ..util.deprecation import deprecated
+from ..core.validation.warnings import MISSING_RENDERERS
 from ..util.plot_utils import _list_attr_splat, _select_helper
 from ..util.string import nice_join
 
@@ -20,10 +19,10 @@ from .glyphs import Glyph
 from .grids import Grid
 from .layouts import LayoutDOM
 from .ranges import Range, FactorRange, DataRange1d, Range1d
-from .renderers import DataRenderer, GlyphRenderer, Renderer, TileRenderer
+from .renderers import GlyphRenderer, Renderer, TileRenderer
 from .scales import Scale, CategoricalScale, LinearScale, LogScale
 from .sources import DataSource, ColumnDataSource
-from .tools import Tool, Toolbar
+from .tools import Tool, Toolbar, HoverTool
 
 def _check_conflicting_kwargs(a1, a2, kwargs):
     if a1 in kwargs and a2 in kwargs:
@@ -162,6 +161,14 @@ class Plot(LayoutDOM):
         legends = [obj for obj in self.renderers if isinstance(obj, Legend)]
         return _list_attr_splat(legends)
 
+    @property
+    def hover(self):
+        ''' Splattable list of :class:`~bokeh.models.tools.HoverTool` objects.
+
+        '''
+        hovers = [obj for obj in self.tools if isinstance(obj, HoverTool)]
+        return _list_attr_splat(hovers)
+
     def _grid(self, dimension):
         grid = [obj for obj in self.renderers if isinstance(obj, Grid) and obj.dimension==dimension]
         return _list_attr_splat(grid)
@@ -195,17 +202,6 @@ class Plot(LayoutDOM):
     def tools(self, tools):
         self.toolbar.tools = tools
 
-    @property
-    def toolbar_sticky(self):
-        deprecated("Plot.toolbar_sticky property is no longer needed, and its use is deprecated."\
-                   "In the future, accessing Plot.toolbar_sticky will result in an AttributeError.")
-        return True
-
-    @toolbar_sticky.setter
-    def toolbar_sticky(self, val):
-        deprecated("Plot.toolbar_sticky property is no longer needed, and its use is deprecated."\
-                   "In the future, accessing Plot.toolbar_sticky will result in an AttributeError.")
-
     def add_layout(self, obj, place='center'):
         ''' Adds an object to the plot in a specified place.
 
@@ -354,11 +350,6 @@ class Plot(LayoutDOM):
         if len(self.renderers) == 0:
             return str(self)
 
-    @warning(NO_DATA_RENDERERS)
-    def _check_no_data_renderers(self):
-        if len(self.select(DataRenderer)) == 0:
-            return str(self)
-
     x_range = Instance(Range, help="""
     The (default) data range of the horizontal dimension of the plot.
     """)
